@@ -16,6 +16,7 @@ from ._thermal_condition import ThermalCondition
 from . import mixture
 from ._thermo import Thermo
 from ._settings import settings
+from ._thermo_data import ThermoData
 from . import (indexer,
                reaction,
                equilibrium
@@ -26,6 +27,6 @@ from .base import functor
 from flexsolve import speed_up
 
 __all__ = ('Chemical', 'Chemicals', 'CompiledChemicals', 'Thermo', 'indexer',
-           'Stream', 'MultiStream', 'ThermalCondition', 'mixture',
+           'Stream', 'MultiStream', 'ThermalCondition', 'mixture', 'ThermoData',
            'settings', 'functor', 'properties', 'base', 'equilibrium',
            'exceptions', 'functional', 'reaction', 'utils', 'speed_up')
