@@ -22,7 +22,7 @@ def must_compile(*args, **kwargs):
 
 def chemical_data_array(chemicals, attr):
     getfield = getattr
-    data = np.array([getfield(i, attr) for i in chemicals])
+    data = np.asarray([getfield(i, attr) for i in chemicals], dtype=float)
     data.setflags(0)
     return data
     
@@ -274,10 +274,10 @@ class CompiledChemicals(Chemicals):
         """
         dct = self.__dict__
         chemicals = self.tuple
-        dct['MW'] = np.array([i.MW for i in chemicals])
-        dct['Hf'] = np.array([i.Hf for i in chemicals])
-        dct['LHV'] = np.array([i.LHV for i in chemicals])
-        dct['HHV'] = np.array([i.HHV for i in chemicals])
+        dct['MW'] = chemical_data_array([i.MW for i in chemicals])
+        dct['Hf'] = chemical_data_array([i.Hf for i in chemicals])
+        dct['LHV'] = chemical_data_array([i.LHV for i in chemicals])
+        dct['HHV'] = chemical_data_array([i.HHV for i in chemicals])
 
     def get_combustion_reactions(self):
         """Return a ParallelReactions object with all defined combustion reactions."""
@@ -303,11 +303,11 @@ class CompiledChemicals(Chemicals):
                 "all missing properties")
         IDs = tuple_([i.ID for i in chemicals])
         CAS = tuple_([i.CAS for i in chemicals])
-        N = len(IDs)
-        index = tuple_(range(N))
+        size = len(IDs)
+        index = tuple_(range(size))
         for i in chemicals: dct[i.CAS] = i
         dct['tuple'] = chemicals
-        dct['size'] = N
+        dct['size'] = size
         dct['IDs'] = IDs
         dct['CASs'] = tuple_([i.CAS for i in chemicals])
         dct['MW'] = chemical_data_array(chemicals, 'MW')
@@ -339,14 +339,31 @@ class CompiledChemicals(Chemicals):
         dct['lle_chemicals'] = tuple_(lle_chemicals)
         dct['heavy_chemicals'] = tuple_(heavy_chemicals)
         dct['light_chemicals'] = tuple_(light_chemicals)
-        dct['_has_vle'] = has_vle = np.zeros(N, dtype=bool)
-        dct['_has_lle'] = has_lle = np.zeros(N, dtype=bool)
+        dct['_has_vle'] = has_vle = np.zeros(size, dtype=bool)
+        dct['_has_lle'] = has_lle = np.zeros(size, dtype=bool)
         dct['_heavy_indices'] = [index[i.ID] for i in heavy_chemicals]
         dct['_light_indices'] = [index[i.ID] for i in light_chemicals]
         vle_index = [index[i.ID] for i in vle_chemicals]
         lle_index = [index[i.ID] for i in lle_chemicals]
         has_vle[vle_index] = True
         has_lle[lle_index] = True
+        
+    @property
+    def formula_array(self):
+        """
+        An array describing the formulas of all chemicals.
+        Each column is a chemical and each row an element.
+        Rows are ordered by atomic number.
+        
+        """
+        try: return self._formula_array
+        except: pass
+        self.__dict__['_formula_array'] = formula_array = np.zeros((118, self.size))
+        atoms_to_array = tmo.properties.elements.atoms_to_array
+        for i, chemical in enumerate(self):
+            formula_array[:, i] = atoms_to_array(chemical.atoms)
+        formula_array.setflags(0)
+        return formula_array
     
     def subgroup(self, IDs):
         """
@@ -502,7 +519,7 @@ class CompiledChemicals(Chemicals):
         
         """
         array = self.array(IDs, data)
-        return ChemicalIndexer.from_data(array, phase=None, chemicals=self)
+        return ChemicalIndexer.from_data(array, chemicals=self)
 
     def ikwarray(self, ID_data):
         """
@@ -534,7 +551,7 @@ class CompiledChemicals(Chemicals):
         
         """
         array = self.kwarray(ID_data)
-        return ChemicalIndexer.from_data(array, phase=None, chemicals=self)
+        return ChemicalIndexer.from_data(array, chemicals=self)
 
     def index(self, ID):
         """
