@@ -152,7 +152,7 @@ class ThermoData:
         """Create a ThermoData object from a json file given its directory."""
         import json
         with open(file, 'r') as stream: 
-            data = json.load(stream)
+            data = json.load(stream.read())
             assert isinstance(data, dict), 'json file must return a dict' 
             return ThermoData(data)
     
