@@ -44,7 +44,8 @@ class Documenter:
         var = functor.var
         if var:
             return_value = self.describe_return_value(var)
-            description = f"Create a {functor.kind} that calcuates {return_value}"
+            description = (f"Create a {functor.kind} that estimates the "
+                           f"{return_value} of a chemical")
             if method:
                 description += f" using the {method} method"
             if ref:
