@@ -4,14 +4,12 @@ Created on Sat Oct 26 04:26:20 2019
 
 @author: yoelr
 """
-from .units_of_measure import chemical_units_of_measure, definitions, types
-from ..utils import var_with_units, get_obj_values, repr_kwargs
-from .documenter import autodoc_functor
+from .units_of_measure import chemical_units_of_measure
+from .. import utils
 from inspect import signature
 
 __all__ = ("functor", "Functor",  "TFunctor", "TPFunctor", "TIntegralFunctor",
-           'H', 'S', 'V', 'Cn', 'mu', 'kappa', 'sigma', 'delta', 'epsilon',
-           'Psat', 'Hvap', 'display_asfunctor', 'functor_lookalike',
+           'display_asfunctor', 'functor_lookalike',
            'functor_matching_params')
 
 REGISTERED_ARGS = set()
@@ -28,7 +26,7 @@ def display_asfunctor(functor, var=None, name=None, show_var=True):
     var = var or (functor.var if hasattr(functor, 'var') else None)
     if var:
         if show_var:
-            info += f" -> " + var_with_units(var, chemical_units_of_measure)
+            info += f" -> " + utils.var_with_units(var, chemical_units_of_measure)
         else:
             name, *_ = var.split('.')
             u = chemical_units_of_measure.get(name)
@@ -47,22 +45,14 @@ def functor_matching_params(params):
         if N <= N_total and base._args == params[:N]: return base
     raise ValueError("could not match function signature to registered functors")
 
-def functor_arguments(function):
-    params = tuple(signature(function).parameters)
-    first_param = params[0]
-    if first_param == 'self':
-        params = params[1:]
-    elif first_param == 'cls':
-        params = params[1:]
-        function = classmethod(function)
-    else:
-        function = staticmethod(function)
+def functor_arguments(params):
     base = functor_matching_params(params)
-    return base, params[base._N_args:], function
+    return base, params[base._N_args:]
+
 
 # %% Decorator
   
-def functor(f=None, var=None, **autodoc):
+def functor(f=None, var=None):
     """
     Decorate a function of temperature, or both temperature and pressure as a Functor subclass.
     
@@ -73,8 +63,6 @@ def functor(f=None, var=None, **autodoc):
         or both temperature and pressure.
     var : str, optional
         Name of variable returned (useful for bookkeeping).
-    **autodoc : 
-        Options to autodoc Functor subclass. By default, the returned Functor subclass is not automatically documented.
     
     Notes
     -----
@@ -103,54 +91,24 @@ def functor(f=None, var=None, **autodoc):
     
     """
     if f:
-        base, params, function = functor_arguments(f)
+        params = tuple(signature(f).parameters)
+        base, params = functor_arguments(params)
         dct = {'__slots__': (),
-               'function': function,
+               'function': staticmethod(f),
                'params': params,
                'var': var}
         cls = type(f.__name__, (base,), dct)
-        if autodoc: autodoc_functor(cls, **autodoc)
         cls.__module__ = f.__module__
-        return cls
     else:
-        return lambda f: functor(f, var, **autodoc)
-
-
-# %% Decorators
-    
-class FunctorFactory:
-    __slots__ = ('var',)
-   
-    def __init__(self, var):
-        self.var = var
-    
-    def __call__(self, function=None, **autodoc):
-        return functor(function, self.var, **autodoc)
-    
-    def s(self, function=None, **autodoc):
-        return functor(function, self.var + '.s', **autodoc)
-    
-    def l(self, function=None, **autodoc):
-        return functor(function, self.var + '.l',  **autodoc)
-    
-    def g(self, function=None, **autodoc):
-        return functor(function, self.var + '.g', **autodoc)
-    
-    def __repr__(self):
-        return f"{type(self).__name__}({repr(self.var)})"
-    
-H, S, Cn, V, kappa, mu, Psat, Hvap, sigma, delta, epsilon = [FunctorFactory(i) for i in
-                                                             ('H', 'S', 'Cn', 'V', 'kappa',
-                                                              'mu', 'Psat', 'Hvap',
-                                                              'sigma', 'delta', 'epsilon')]
+        return lambda f: functor(f, var)
+    return cls
 
 
 # %% Functors
 
 class Functor:
     __slots__ = ('__dict__',)
-    definitions = definitions
-    types = types
+
     def __init_subclass__(cls, args=None):
         if args:
             cls._args = args = tuple(args)
@@ -168,8 +126,7 @@ class Functor:
         self.__dict__ = kwargs
     
     def set_value(self, var, value):
-        if var in self.__dict__:
-            self.__dict__[var] = value
+        if var in self.__dict__: self.__dict__[var] = value
     
     def copy(self):
         cls = self.__class__
@@ -177,11 +134,6 @@ class Functor:
         new.__dict__ = self.__dict__.copy()
         return new
     
-    def load_data_from(self, data: dict):
-        dct = self.__dict__
-        keys = dct.keys() & data.keys()
-        for i in keys: dct[i] = data[i]
-    
     @classmethod
     def from_other(cls, other):
         self = cls.__new__(cls)
@@ -203,13 +155,16 @@ class Functor:
     @classmethod
     def from_obj(cls, data):
         self = cls.__new__(cls)
-        self.__dict__ = dict(zip(self.params, get_obj_values(data, self.params)))
+        self.__dict__ = dict(zip(self.params, utils.get_obj_values(data, self.params)))
         return self
     
-    def _object_info(self):
-        return f"{type(self).__name__}({repr_kwargs(self.__dict__, start='')})"
+    def __str__(self):
+        return display_asfunctor(self)
     
-    def _functor_info(self):
+    def __repr__(self):
+        return f"<{self}>"
+    
+    def show(self):
         info = f"Functor: {display_asfunctor(self)}"
         data = self.__dict__
         for key, value in data.items():
@@ -225,36 +180,6 @@ class Functor:
                 key, *_ = key.split('_')
                 u = chemical_units_of_measure.get(key)
                 if u: info += ' ' + str(u)
-        return info
-    
-    def __str__(self):
-        return display_asfunctor(self)
-    
-    def __repr__(self):
-        return f"<{self}>"
-    
-    def _example_info(self, **kwargs):
-        obj_info = self._object_info()
-        f_info = self._functor_info()
-        f_info.replace('\n', 4*' ')
-        value = self(**kwargs)
-        call_sig = repr_kwargs(kwargs, start="")
-        return (f">>> f = {obj_info}\n"
-                f">>> f\n"
-                f"{f_info}\n"
-                f">>> f({call_sig})\n"
-                f"{value}")
-    
-    def _show_example(self, **kwargs):
-        print(self._example_info(**kwargs))
-    
-    def show(self, format='functor'):
-        if format == 'object':
-            info = self._object_info()
-        elif format == 'functor':
-            info = self._functor_info()
-        else:
-            raise ValueError(f"format must be either 'functor' or 'object', not {repr(format)}")
         print(info)
         
     _ipython_display_ = show
