@@ -10,8 +10,8 @@ __all__ = ('DDBST_UNIFAC_assignments',
            'DortmundGroupCounts',
            'PSRKGroupCounts')
 import os
-
-folder = os.path.join(os.path.dirname(__file__), 'Data')
+import json
+from .. import utils
 
 # %% Data
 
@@ -812,47 +812,18 @@ PSRKSG[148] = UNIFAC_subgroup('O3', 84, 'O3', 1.1000, 1.2700)
 PSRKSG[149] = UNIFAC_subgroup('CLNO', 85, 'CLNO', 1.4800, 1.3400)
 PSRKSG[152] = UNIFAC_subgroup('CNH2', 14, 'CNH2', 0.9147, 0.6140)
 
-UFIP = {i: {} for i in list(range(1, 52)) + [55, 84, 85]}
-with open(os.path.join(folder, 'UNIFAC original interaction parameters.tsv')) as f:
-    for line in f:
-        maingroup1, maingroup2, interaction_parameter = line.strip(
-            '\n').split('\t')
-        # Index by both int, order maters, to only one parameter.
-        UFIP[int(maingroup1)][int(maingroup2)] = float(interaction_parameter)
+def keys2int(x):
+    if isinstance(x, dict):
+        to_int = int
+        return {to_int(k):v for k,v in x.items()}
+    return x
 
-DOUFIP2006 = {i: {} for i in DOUFMG.keys()}
-with open(os.path.join(folder, 'UNIFAC modified Dortmund interaction parameters 2006.tsv')) as f:
-    for line in f:
-        maingroup1, maingroup2, a, b, c = line.strip('\n').split('\t')
-        DOUFIP2006[int(maingroup1)][int(maingroup2)] = (
-            float(a), float(b), float(c))
-
-DOUFIP2016 = {i: {} for i in list(DOUFMG.keys())+[50, 77, 98, 99]}
-# Some of the groups have no public parameters unfortunately
-with open(os.path.join(folder, 'UNIFAC modified Dortmund interaction parameters.tsv')) as f:
-    for line in f:
-        maingroup1, maingroup2, a, b, c = line.strip('\n').split('\t')
-        DOUFIP2016[int(maingroup1)][int(maingroup2)] = (
-            float(a), float(b), float(c))
-
-
-#NISTUFIP = {i: {} for i in list(NISTUFMG.keys())}
-NISTUFIP = {i: {} for i in range(400)}
-
-with open(os.path.join(folder, 'UNIFAC modified NIST 2015 interaction parameters.tsv')) as f:
-    for line in f:
-        maingroup1, maingroup2, a, b, c, Tmin, Tmax = line.strip(
-            '\n').split('\t')
-        NISTUFIP[int(maingroup1)][int(maingroup2)] = (
-            float(a), float(b), float(c))
-
-PSRKIP = {i: {} for i in range(400)}
-
-with open(os.path.join(folder, 'PSRK interaction parameters.tsv')) as f:
-    for line in f:
-        maingroup1, maingroup2, a, b, c = line.strip('\n').split('\t')
-        PSRKIP[int(maingroup1)][int(maingroup2)] = (
-            float(a), float(b), float(c))
+folder = os.path.join(os.path.dirname(__file__), 'Data')
+UFIP = utils.load_json(folder, 'UNIFAC original interaction parameters.json', keys2int)
+DOUFIP2016 = utils.load_json(folder, 'UNIFAC modified Dortmund interaction parameters.json', keys2int)
+NISTUFIP = utils.load_json(folder, 'UNIFAC modified NIST 2015 interaction parameters.json', keys2int)
+PSRKIP = utils.load_json(folder, 'PSRK interaction parameters.json', keys2int)
+del keys2int
 
 
 # %% Assignments
@@ -865,6 +836,18 @@ class GroupCounts(dict):
         cls.ids_by_group_name = {subgroup.group: key
                                  for key, subgroup in subgroups_by_id.items()}
     
+    def __init__(self, dict=None):
+        if dict: 
+            to_int = int
+            super().__init__({to_int(i): j for i,j in dict.items()})
+        
+    @classmethod
+    def from_json_dict(cls, dict):
+        to_int = int
+        self = cls()
+        for i,j in dict.items(): self[to_int(i)] = j
+        return self
+        
     def set_group_counts_by_name(self, group_counts: dict):
         self.clear()
         ids_by_group_name = self.ids_by_group_name
@@ -895,9 +878,11 @@ class GroupCounts(dict):
 class UNIFACGroupCounts(GroupCounts):
     __slots__ = ()
     subgroups_by_id = UFSG
+    
 class DortmundGroupCounts(GroupCounts):
     __slots__ = ()
     subgroups_by_id = DOUFSG 
+    
 class PSRKGroupCounts(GroupCounts):
     __slots__ = ()
     subgroups_by_id = PSRKSG
@@ -912,34 +897,11 @@ class GroupAssigner:
     def __setitem__(self, key, count):
         self.group_counts[key] = count
 
-DDBST_UNIFAC_assignments = {}
-DDBST_MODIFIED_UNIFAC_assignments = {}
-DDBST_PSRK_assignments = {}
-class UNIFACGroupAssigner(GroupAssigner):
-    assignments = DDBST_UNIFAC_assignments
-    GroupCounts = UNIFACGroupCounts
-class DortmundGroupAssigner(GroupAssigner):
-    assignments = DDBST_MODIFIED_UNIFAC_assignments
-    GroupCounts = DortmundGroupCounts
-class PSRKGroupAssigner(GroupAssigner):
-    assignments = DDBST_PSRK_assignments
-    GroupCounts = PSRKGroupCounts
-
-_assigners = (UNIFACGroupAssigner,
-              DortmundGroupAssigner,
-              PSRKGroupAssigner)
-
-with open(os.path.join(folder, 'DDBST UNIFAC assignments.tsv')) as f:
-    for line in f.readlines():
-        InChI_key, valids, *original_modified_PSRK = line.split('\t')
-        # list of whether or not each method was correctly identified or not
-        valids = [i == '1' for i in valids.split(' ')]
-        for Assigner, groups, valid in zip(_assigners, original_modified_PSRK, valids):
-            if valid:
-                groups = groups.rstrip().split(' ')
-                assigner = Assigner(InChI_key)
-                for i in range(int(len(groups)/2)):
-                    index = i*2
-                    assigner[int(groups[index])] = int(groups[index+1])
-
+data = utils.load_json(folder, 'DDBST UNIFAC-original assignments.json')
+DDBST_UNIFAC_assignments = {i: UNIFACGroupCounts.from_json_dict(j) for i,j in data.items()}
+data = utils.load_json(folder, 'DDBST UNIFAC-Dortmund assignments.json')
+DDBST_MODIFIED_UNIFAC_assignments = {i: DortmundGroupCounts.from_json_dict(j) for i,j in data.items()}
+data = utils.load_json(folder, 'DDBST UNIFAC-original assignments.json')
+DDBST_PSRK_assignments = {i: PSRKGroupCounts.from_json_dict(j) for i,j in data.items()}
+del data
 
