@@ -5,6 +5,7 @@ Created on Wed Mar 20 18:40:05 2019
 @author: yoelr
 """
 import flexsolve as flx
+from ..exceptions import InfeasibleRegion
 from ..utils.decorator_utils import thermo_user
 from . import binary_phase_fraction as binary
 from .dew_point import DewPointCache
@@ -321,7 +322,8 @@ class VLE:
         
     def _lever_rule(self, x, y):
         split_frac = (self._z[0]-x[0])/(y[0]-x[0])
-        assert -0.00001 < split_frac < 1.00001, 'desired composition is infeasible'
+        if not -0.00001 < split_frac < 1.00001:
+            InfeasibleRegion('phase composition')
         if split_frac > 1:
             split_frac = 1
         elif split_frac < 0:
