@@ -3,7 +3,6 @@
 Functional utilities for the calculation of thermodynamic properties.
 
 """
-from fluids.core import thermal_diffusivity
 from cmath import sqrt as csqrt
 from flexsolve import njitable
 from .base import functor
@@ -18,7 +17,7 @@ __all__ = ('isobaric_expansion', 'isothermal_compressibility',
            'Z_from_virial_pressure_form', 'zs_to_ws', 'ws_to_zs', 'zs_to_Vfs', 
            'Vfs_to_zs', 'none_and_length_check', 'normalize', 'mixing_simple', 
            'mixing_logarithmic', 'Parachor', 'SG_to_API', 'API_to_SG', 'SG',
-           'horner', 'allclose_variable', 'polylog2', 'horner', 'thermal_diffusivity'
+           'horner', 'allclose_variable', 'polylog2', 'horner',
 )
 
 @functor
