@@ -74,9 +74,16 @@ class Indexer:
         return new
     __copy__ = copy
     
+    def get_conversion_factor(self, units):
+        if self.units:
+            return self.units.conversion_factor(units)
+        else:
+            raise TypeError(f"{type(self).__name__} object is unitless; "
+                            f"cannot get conversion factor for {units}")
+    
     def get_data(self, units, *index):
         length = len(index)
-        factor = self.units.conversion_factor(units)
+        factor = self.get_conversion_factor(units)
         if length == 0:
             return factor * self._data
         elif length == 1:
@@ -87,7 +94,8 @@ class Indexer:
     def set_data(self, data, units, *index):
         length = len(index)
         data = np.asarray(data, dtype=float)
-        scaled_data = data / self.units.conversion_factor(units)
+        factor = self.get_conversion_factor(units)
+        scaled_data = data / factor
         if length == 0:
             self._data[:] = scaled_data
         elif length == 1:
@@ -304,8 +312,7 @@ class MaterialIndexer(Indexer):
             for phase, ID_data in phase_data.items():
                 IDs, row = zip(*ID_data)
                 data[phase_index(phase), get_index(IDs)] = row
-            if units:
-                self.set_data(data, units)
+            if units: self.set_data(data, units)
         return self
     
     def __reduce__(self):
