@@ -12,18 +12,14 @@ from . import (acentric,
                dippr,
                electrolytes,
                elements,
-               environment,
                eos,
                heat_capacity,
                identifiers,
-               joback,
                lennard_jones,
                miscdata,
                permittivity,
                phase_change,
                reaction,
-               refractivity,
-               solubility,
                interface,
                thermal_conductivity,
                triple,
@@ -34,14 +30,13 @@ from . import (acentric,
                volume)
 
 __all__ = ('combustion', 'electrolyte_conductivity', 'critical', 'dipole',
-           'electrolytes', 'elements', 'environment',
+           'electrolytes', 'elements', 
            'eos', 'heat_capacity',  'identifiers', 
-           'joback', 'lennard_jones', 'miscdata',
+           'lennard_jones', 'miscdata',
            'permittivity', 'phase_change',  'reaction', 
-           'refractivity', 'solubility',
            'interface', 'thermal_conductivity', 'triple', 
            'utils', 'vapor_pressure', 'virial',
 		   'viscosity', 'volume', 'acentric', 
-           'datasheet', 'dippr',)
+           'dippr',)
 
 
