@@ -74,12 +74,30 @@ References
 .. [17] Yaws, Carl L. Thermophysical Properties of Chemicals and
    Hydrocarbons, Second Edition. Amsterdam Boston: Gulf Professional
    Publishing, 2014.
+.. [18] Mersmann, Alfons, and Matthias Kind. "Correlation for the Prediction
+    of Critical Molar Volume." Industrial & Engineering Chemistry Research,
+    October 16, 2017. https://doi.org/10.1021/acs.iecr.7b03171.
+.. [19] Mersmann, Alfons, and Matthias Kind. "Prediction of Mechanical and 
+   Thermal Properties of Pure Liquids, of Critical Data, and of Vapor 
+   Pressure." Industrial & Engineering Chemistry Research, January 31, 
+   2017. https://doi.org/10.1021/acs.iecr.6b04323.
+.. [20] Ihmels, E. Christian. "The Critical Surface." Journal of Chemical
+    & Engineering Data 55, no. 9 (September 9, 2010): 3474-80.
+    doi:10.1021/je100167w.
+.. [21] Meissner, H. P., and E. M. Redding. "Prediction of Critical
+    Constants." Industrial & Engineering Chemistry 34, no. 5
+    (May 1, 1942): 521-26. doi:10.1021/ie50389a003.
+.. [22] Grigoras, Stelian. "A Structural Approach to Calculate Physical
+    Properties of Pure Organic Substances: The Critical Temperature,
+    Critical Volume and Related Properties." Journal of Computational
+    Chemistry 11, no. 4 (May 1, 1990): 493-510.
+    doi:10.1002/jcc.540110408
 
 """
 
 from collections import namedtuple
 from .utils import CASDataReader, get_from_data_sources
-from .._constants import R, N_A
+from .._constants import N_A
 
 __all__ = ('critical_point_temperature',
            'critical_point_pressure',
@@ -328,7 +346,7 @@ rcovs_regressed =  {
 def Mersmann_Kind_predictor(atoms, coeff=3.645, power=0.5, 
                             covalent_radii=rcovs_Mersmann_Kind):
     r'''Predicts the critical molar volume of a chemical based only on its
-    atomic composition according to [1]_ and [2]_. This is a crude approach,
+    atomic composition according to [18]_ and [19]_. This is a crude approach,
     but provides very reasonable
     estimates in practice. Optionally, the `coeff` used and the `power` in the
     fraction as well as the atomic contributions can be adjusted; this method
@@ -393,15 +411,6 @@ def Mersmann_Kind_predictor(atoms, coeff=3.645, power=0.5,
     error is 5.0%; standard deviation 6.8%; and worst value of 79% relative
     error for phosphorus.
     
-    References
-    ----------
-    .. [1] Mersmann, Alfons, and Matthias Kind. "Correlation for the Prediction
-       of Critical Molar Volume." Industrial & Engineering Chemistry Research,
-       October 16, 2017. https://doi.org/10.1021/acs.iecr.7b03171.
-    .. [2] Mersmann, Alfons, and Matthias Kind. "Prediction of Mechanical and 
-       Thermal Properties of Pure Liquids, of Critical Data, and of Vapor 
-       Pressure." Industrial & Engineering Chemistry Research, January 31, 
-       2017. https://doi.org/10.1021/acs.iecr.6b04323.
     '''
     H_RADIUS_COV = covalent_radii['H']
     tot = 0
@@ -426,7 +435,7 @@ def Ihmels(Tc=None, Pc=None, Vc=None):
     properties from each other. Two of the three properties are required.
     This model uses the "critical surface", a general plot of Tc vs Pc vs Vc.
     The model used 421 organic compounds to derive equation.
-    The general equation is in [1]_:
+    The general equation is in [20]_:
 
     .. math::
         P_c = -0.025 + 2.215 \frac{T_c}{V_c}
@@ -461,11 +470,6 @@ def Ihmels(Tc=None, Pc=None, Vc=None):
     >>> Ihmels(Tc=851.0, Vc=0.000308)
     6095016.233766234
 
-    References
-    ----------
-    .. [1] Ihmels, E. Christian. "The Critical Surface." Journal of Chemical
-           & Engineering Data 55, no. 9 (September 9, 2010): 3474-80.
-           doi:10.1021/je100167w.
     '''
     critical_point = CriticalPoint(Tc, Pc, Vc)
     if Tc and Vc:
@@ -491,7 +495,7 @@ def Meissner(Tc=None, Pc=None, Vc=None):
     properties from each other. Two of the three properties are required.
     This model uses the "critical surface", a general plot of Tc vs Pc vs Vc.
     The model used 42 organic and inorganic compounds to derive the equation.
-    The general equation is in [1]_:
+    The general equation is in [21]_:
 
     .. math::
         P_c = \frac{2.08 T_c}{V_c-8}
@@ -526,11 +530,6 @@ def Meissner(Tc=None, Pc=None, Vc=None):
     >>> Meissner(Tc=851.0, Vc=0.000308)
     5978445.199999999
 
-    References
-    ----------
-    .. [1] Meissner, H. P., and E. M. Redding. "Prediction of Critical
-           Constants." Industrial & Engineering Chemistry 34, no. 5
-           (May 1, 1942): 521-26. doi:10.1021/ie50389a003.
     '''
     critical_point = CriticalPoint(Tc, Pc, Vc)
     if Tc and Vc:
@@ -555,7 +554,7 @@ def Grigoras(Tc=None, Pc=None, Vc=None):
     properties from each other. Two of the three properties are required.
     This model uses the "critical surface", a general plot of Tc vs Pc vs Vc.
     The model used 137 organic and inorganic compounds to derive the equation.
-    The general equation is in [1]_:
+    The general equation is in [22]_:
 
     .. math::
         P_c = 2.9 + 20.2 \frac{T_c}{V_c}
@@ -590,13 +589,6 @@ def Grigoras(Tc=None, Pc=None, Vc=None):
     >>> Grigoras(Tc=851.0, Vc=0.000308)
     5871233.766233766
 
-    References
-    ----------
-    .. [1] Grigoras, Stelian. "A Structural Approach to Calculate Physical
-           Properties of Pure Organic Substances: The Critical Temperature,
-           Critical Volume and Related Properties." Journal of Computational
-           Chemistry 11, no. 4 (May 1, 1990): 493-510.
-           doi:10.1002/jcc.540110408
     '''
     critical_point = CriticalPoint(Tc, Pc, Vc)
     if Tc and Vc:
@@ -615,6 +607,3 @@ def Grigoras(Tc=None, Pc=None, Vc=None):
         raise ValueError('Two of Tc, Pc, and Vc must be provided')
     return critical_point
 
-
-
-
