@@ -3,8 +3,6 @@
 All data and functions for using the Joback group contribution method.
 '''
 
-from __future__ import division
-
 __all__ = ['smarts_fragment', 'Joback', 'J_BIGGS_JOBACK_SMARTS', 
            'J_BIGGS_JOBACK_SMARTS_id_dict']
 
@@ -15,8 +13,6 @@ from ..functional import horner_polynomial
 from .utils import to_nums
 try:
     from rdkit import Chem
-    from rdkit.Chem import Descriptors
-    from rdkit.Chem import AllChem
     from rdkit.Chem import rdMolDescriptors
     hasRDKit = True
 except:
