@@ -6,10 +6,8 @@ __all__ = ('inorganic_data_CRC',
            'organic_data_CRC', 
            'VDI_saturation_dict', 
            'VDI_tabular_data')
-import os
-import copy
-from .utils import to_nums, CASDataReader
-from ..functional import rho_to_V
+from .utils import CASDataReader
+from ..utils import load_json
 
 read = CASDataReader(__file__, 'Misc')
 
@@ -18,51 +16,14 @@ inorganic_data_CRC = read('Physical Constants of Inorganic Compounds.csv')
 organic_data_CRC = read('Physical Constants of Organic Compounds.csv')
 
 ### VDI Saturation
-
-emptydict = {"Name": None, "MW": None, "Tc": None, "T": [], "P": [],
-             "Density (l)": [], "Density (g)": [], "Hvap": [], "Cp (l)": [],
-            "Cp (g)": [], "Mu (l)": [], "Mu (g)": [], "K (l)": [], "K (g)": [],
-            "Pr (l)": [], "Pr (g)": [], "sigma": [], "Beta": [],
-            "Volume (l)": [], "Volume (g)": []}
-
-# After some consideration, it has been devided to keep this load method as is.
-
-VDI_saturation_dict = {}
-with open(os.path.join(read.folder, 'VDI Saturation Compounds Data.csv')) as f:
-    '''Read in a dict of assorted chemical properties at saturation for 58
-    industrially important chemicals, from:
-    Gesellschaft, V. D. I., ed. VDI Heat Atlas. 2E. Berlin : Springer, 2010.
-    This listing is the successor to that in:
-    Schlunder, Ernst U, and International Center for Heat and Mass Transfer.
-    Heat Exchanger Design Handbook. Washington: Hemisphere Pub. Corp., 1983.
-    '''
-    next(f)
-    for line in f:
-        values = to_nums(line.strip('\n').split('\t'))
-        (CASRN, _name, _MW, _Tc, T, P, rhol, rhog, Hvap, cpl, cpg, mul, mug, kl, kg, prl, prg, sigma, Beta) = values
-        newdict = (VDI_saturation_dict[CASRN] if CASRN in VDI_saturation_dict else copy.deepcopy(emptydict))
-        newdict["Name"] = _name
-        newdict["MW"] = _MW
-        newdict["Tc"] = _Tc
-        newdict["T"].append(T)
-        newdict["P"].append(P)
-        newdict["Density (l)"].append(rhol)
-        newdict["Density (g)"].append(rhog)  # Not actually used
-        newdict["Hvap"].append(Hvap)
-        newdict["Cp (l)"].append(cpl)  # Molar
-        newdict["Cp (g)"].append(cpg)  # Molar
-        newdict["Mu (l)"].append(mul)
-        newdict["Mu (g)"].append(mug)
-        newdict["K (l)"].append(kl)
-        newdict["K (g)"].append(kg)
-        newdict["Pr (l)"].append(prl)
-        newdict["Pr (g)"].append(prl)
-        newdict["sigma"].append(sigma)
-        newdict["Beta"].append(Beta)
-        newdict["Volume (l)"].append(rho_to_V(rhol, _MW))
-        newdict["Volume (g)"].append(rho_to_V(rhog, _MW))
-        VDI_saturation_dict[CASRN] = newdict
-
+VDI_saturation_dict = load_json(read.folder, 'VDI Saturation Compounds Data.json')
+#: Read in a dict of assorted chemical properties at saturation for 58
+#: industrially important chemicals, from:
+#: Gesellschaft, V. D. I., ed. VDI Heat Atlas. 2E. Berlin : Springer, 2010.
+#: This listing is the successor to that in:
+#: Schlunder, Ernst U, and International Center for Heat and Mass Transfer.
+#: Heat Exchanger Design Handbook. Washington: Hemisphere Pub. Corp., 1983.
+#: keys are CASRN and data for each chemical are in standard thermosteam units.
 
 def VDI_tabular_data(CASRN, prop):
     r'''This function retrieves the tabular data available for a given chemical
