@@ -66,7 +66,7 @@ __all__ = ('heat_of_vaporization_handle',
 )
 
 import numpy as np
-from ..base import InterpolatedTDependentModel, TDependentHandleBuilder, Hvap
+from ..base import InterpolatedTDependentModel, TDependentHandleBuilder, functor
 from .._constants import R, N_A
 from math import log, pi
 from .utils import CASDataReader, get_from_data_sources
@@ -213,10 +213,24 @@ def normal_melting_point_temperature(CASRN, method='Any'):
 
 ### Enthalpy of Vaporization at T
 
-@Hvap(ref="[5]_",
-      types={'dZ': 'function(T)', 'Psat': 'function(T)'})
+@functor(var='Hvap')
 def Clapeyron(T, Tc, Pc, V, Psat):
     r"""
+    Create a functor of temperature (T; in K) that estimates the heat of 
+    vaporization (Hvap; in J/mol) of a chemical using the Clapeyron method, 
+    as described in [5]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    Pc : float
+        Critical point pressure [Pa].
+    V : float
+        Molar volume [m^3/mol].
+    Psat : function(T)
+        Saturated vapor pressure [Pa].
+    
     Notes
     -----
     The enthalpy of vaporization (Hvap; in J/mol) is given by:
@@ -244,9 +258,18 @@ def Clapeyron(T, Tc, Pc, V, Psat):
     P = Psat(T)
     return R*T*fn.Z(T, P, V.g(T, P))*log(Pc/P)/(1. - Tr)
 
-@Hvap(ref="[5]_ [6]_")
+@functor(var='Hvap')
 def Pitzer(T, Tc, omega):
     r"""
+    Create a functor of temperature (T; in K) that estimates the heat of vaporization (Hvap; in J/mol) of a chemical using the Pitzer method, as described in [5]_ [6]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    omega : float
+        Acentric factor [-].
+    
     Notes
     -----
     
@@ -273,9 +296,20 @@ def Pitzer(T, Tc, omega):
     Tr = T/Tc
     return R*Tc * (7.08*(1. - Tr)**0.354 + 10.95*omega*(1. - Tr)**0.456)
 
-@Hvap(ref="[8]_")
+@functor(var='Hvap')
 def SMK(T, Tc, omega):
     r"""
+    Create a functor of temperature (T; in K) that estimates the heat of
+    vaporization (Hvap; in J/mol) of a chemical using the SMK method, as
+    described in [8]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    omega : float
+        Acentric factor [-].
+    
     Notes
     -----
     The enthalpy of vaporization (Hvap; in J/mol) is given by:
@@ -339,9 +373,20 @@ def SMK(T, Tc, omega):
     domega = (omega - omegaR1)/(omegaR2 - omegaR1)
     return R*Tc*(L0 + domega*L1)
 
-@Hvap(ref="[9]_")
+@functor(var='Hvap')
 def MK(T, Tc, omega):
     r"""
+    Create a functor of temperature (T; in K) that estimates the heat of 
+    vaporization (Hvap; in J/mol) of a chemical using the MK method, as 
+    described in [9]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    omega : float
+        Acentric factor [-].
+    
     Notes
     -----
     The enthalpy of vaporization (Hvap; in J/mol) is given by:
@@ -394,9 +439,20 @@ def MK(T, Tc, omega):
 
     return H0 + omega*H1 + omega**2*H2
 
-@Hvap(ref="[10]_")
+@functor(var='Hvap')
 def Velasco(T, Tc, omega):
     r"""
+    Create a functor of temperature (T; in K) that estimates the heat of 
+    vaporization (Hvap; in J/mol) of a chemical using the Velasco method, as 
+    described in [10]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    omega : float
+        Acentric factor [-].
+    
     Notes
     -----
     The enthalpy of vaporization (Hvap; in J/mol) is given by:
@@ -623,21 +679,22 @@ def Vetere(Tb, Tc, Pc, F=1):
 
 
 ### Enthalpy of Vaporization adjusted for T
-@Hvap
+@functor(var='Hvap')
 def Watson(T, Hvap_ref, T_ref, Tc, exponent=0.38):
     '''
-    Adjusts enthalpy of vaporization of enthalpy for another temperature, for one temperature.
+    Adjusts enthalpy of vaporization of enthalpy for another temperature,
+    for one temperature.
     '''
     Tr = T/Tc
     Trefr = T_ref/Tc
     H2 = Hvap_ref*((1-Tr)/(1-Trefr))**exponent
     return H2
 
-@Hvap
+@functor(var='Hvap')
 def Alibakhshi(T, Tc, C):
     return (4.5*pi*N_A)**(1./3.)*4.2E-7*(Tc-6.) - R/2.*T*log(T) + C*T
 
-@Hvap
+@functor(var='Hvap')
 def VDI_PPDS(T, Tc, A, B, C, D, E):
     tau = 1. - T/Tc
     return R*Tc*(A*tau**(1/3.) + B*tau**(2/3.) + C*tau + D*tau**2 + E*tau**6)
