@@ -33,7 +33,11 @@ References
 from math import exp
 from .utils import CASDataReader
 from ..functional import horner_polynomial
-from ..base import InterpolatedTDependentModel, mu, TPDependentHandleBuilder, TDependentModel, PhaseTPHandleBuilder
+from ..base import (InterpolatedTDependentModel, 
+                    TPDependentHandleBuilder, 
+                    TDependentModel, 
+                    PhaseTPHandleBuilder,
+                    functor)
 from .miscdata import VDI_saturation_dict, VDI_tabular_data
 # from .electrochem import _Laliberte_Viscosity_ParametersDict, Laliberte_viscosity
 from .dippr import DIPPR_EQ101, DIPPR_EQ102
@@ -61,9 +65,18 @@ _Perrys2_312 = read('Table 2-312 Vapor Viscosity of Inorganic and Organic Substa
 _VDI_PPDS_7 = read('VDI PPDS Dynamic viscosity of saturated liquids polynomials.tsv')
 _VDI_PPDS_8 = read('VDI PPDS Dynamic viscosity of gases polynomials.tsv')
 
-@mu.l(ref='[1]_')
-def Viswanath_Natarajan2(T, A, B):
-    '''
+@functor(var='mu.l')
+def Viswanath_Natarajan2(T, a, b):
+    """
+    Create a functor of temperature (T; in K) that estimates the liquid 
+    hydraulic viscosity (mu.l; in Pa*s) of a chemical using the
+    Viswanath Natarajan method #2, as described in [1]_.
+    
+    Parameters
+    ----------
+    a,b : float
+        Regressed coefficients.
+    
     Notes
     -----
     This method is known to produce values 10 times too low.
@@ -74,12 +87,21 @@ def Viswanath_Natarajan2(T, A, B):
     >>> f(348.15)
     0.00045983686956829517
     
-    '''
-    return exp(A + B/T) / 100.
+    """
+    return exp(a + b/T) / 100.
 
-@mu.l(ref='[1]_')
-def Viswanath_Natarajan3(T, A, B, C):
-    r'''
+@functor(var='mu.l')
+def Viswanath_Natarajan3(T, a, b, c):
+    r"""
+    Create a functor of temperature (T; in K) that estimates the liquid 
+    hydraulic viscosity (mu.l; in Pa*s) of a chemical using the Viswanath
+    Natarajan method #3, as described in [1]_.
+    
+    Parameters
+    ----------
+    a,b,c : float
+        Regressed coefficients.
+        
     Notes
     -----
     Calculates the viscosity of a liquid using the 3-term Antoine form
@@ -88,7 +110,7 @@ def Viswanath_Natarajan3(T, A, B, C):
     coefficients found so far have been.
     
     .. math::
-        \log_{10} \mu = A + B/(T + C)
+        \log_{10} \mu = a + b/(T + c)
     
     No other source for these coefficients has been found.
     
@@ -97,12 +119,27 @@ def Viswanath_Natarajan3(T, A, B, C):
     >>> ViswanathNatarajan3(298.15, -2.7173, -1071.18, -129.51)
     0.0006129806445142112
     
-    '''
-    return 10**(A + B/(C - T))/1000.
+    """
+    return 10**(a + b/(c - T))/1000.
 
-@mu.l(ref='[2]_')
+@functor(var='mu.l')
 def Letsou_Stiel(T, MW, Tc, Pc, omega):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) that estimates the liquid 
+    hydraulic viscosity (mu.l; in Pa*s) of a chemical using the Letsou Stiel 
+    method, as described in [2]_.
+    
+    Parameters
+    ----------
+    MW : float
+        Molecular weight [g/mol].
+    Tc : float
+        Critical point temperature [K].
+    Pc : float
+        Critical point pressure [Pa].
+    omega : float
+        Acentric factor [-].
+        
     Notes
     -----
     Calculates the viscosity of a liquid using an emperical model
@@ -131,16 +168,37 @@ def Letsou_Stiel(T, MW, Tc, Pc, omega):
     >>> f(400.)
     0.0002036150875308151
     
-    '''
+    """
     Tr = T/Tc
     xi0 = (1.5174-2.135*Tr + 0.75*Tr**2)*1E-5
     xi1 = (4.2552-7.674*Tr + 3.4*Tr**2)*1E-5
     xi = 2173.424*Tc**(1/6.)/(MW**0.5*Pc**(2/3.))
     return (xi0 + omega*xi1)/xi
 
-@mu.l(ref='[3]_')
+@functor(var='mu.l')
 def Przedziecki_Sridhar(T, Tm, Tc, Pc, Vc, V, omega, MW):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) that estimates the liquid 
+    hydraulic viscosity (mu.l; in Pa*s) of a chemical using the Przedziecki 
+    Sridhar method, as described in [3]_.
+    
+    Parameters
+    ----------
+    Tm : float
+        Melting point temperature [K].
+    Tc : float
+        Critical point temperature [K].
+    Pc : float
+        Critical point pressure [Pa].
+    Vc : float
+        Critical point volume [m^3/mol].
+    V : float
+        Molar volume [m^3/mol].
+    omega : float
+        Acentric factor [-].
+    MW : float
+        Molecular weight [g/mol].
+    
     Notes
     -----
     Calculates the viscosity of a liquid using an emperical formula
@@ -164,7 +222,7 @@ def Przedziecki_Sridhar(T, Tm, Tc, Pc, Vc, V, omega, MW):
     >>> f(383.)
     0.0002198147995603383
     
-    '''
+    """
     Pc = Pc/1E5  # Pa to atm
     V, Vc = V*1E6, Vc*1E6  # m^3/mol to mL/mol
     Tr = T/Tc
@@ -176,19 +234,34 @@ def Przedziecki_Sridhar(T, Tm, Tc, Pc, Vc, V, omega, MW):
     E = -1.12 + Vc/(12.94 + 0.1*MW - 0.23*Pc + 0.0424*Tm - 11.58*(Tm/Tc))
     return Vo/(E*(V-Vo))/1000.
 
-@mu.l(method="VDI-PPDS")
-def VDI(T, A, B, C, D, E):
-    term = (C - T)/(T-D)
+@functor(var='mu.l')
+def VDI(T, a, b, c, d, e):
+    """
+    Create a functor of temperature (T; in K) that estimates the liquid 
+    hydraulic viscosity (mu.l; in Pa*s) of a chemical using the VDI-PPDS, 
+    as described in [1]_.
+    
+    Parameters
+    ----------
+    a,b,c,d,e : float
+        Regressed coefficients.
+
+    """
+    term = (c - T)/(T-d)
     if term < 0:
-        term1 = -((T - C)/(T-D))**(1/3.)
+        term1 = -((T - c)/(T-d))**(1/3.)
     else:
         term1 = term**(1/3.)
     term2 = term*term1
-    return E*exp(A*term1 + B*term2)
+    return e*exp(a*term1 + b*term2)
 
-@mu.l(doc='auto-header', ref='[4]_ [5]_')
+@functor(var='mu.l')
 def Lucas_liquid(T, P, Tc, Pc, omega, Psat, mu_l):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) and pressure (P; in Pa) that
+    estimates the liquid hydraulic viscosity (mu.l; in Pa*s) of a chemical
+    using the Lucas liquid method, as described in [4]_ [5]_.
+    
     Parameters
     ----------
     T : float
@@ -204,7 +277,7 @@ def Lucas_liquid(T, P, Tc, Pc, omega, Psat, mu_l):
     Psat : function(T)
         Saturation pressure of the fluid [Pa]
     mu_l : function(T, P)
-        Viscosity of liquid at 1 atm or saturation, [Pa*S]
+        Viscosity of liquid at 1 atm or saturation, [Pa*s]
     
     Notes
     -----
@@ -219,7 +292,7 @@ def Lucas_liquid(T, P, Tc, Pc, omega, Psat, mu_l):
     >>> f(300.)
     0.0010683738499316518
     
-    '''
+    """
     Tr = T/Tc
     C = -0.07921+2.1616*Tr - 13.4040*Tr**2 + 44.1706*Tr**3 - 84.8291*Tr**4 \
         + 96.1209*Tr**5-59.8127*Tr**6+15.6719*Tr**7
@@ -272,9 +345,22 @@ def viscosity_liquid_handle(handle, CAS, MW, Tm, Tc, Pc, Vc, omega, Psat, Vl):
 
 
 ### Viscosity of Gases - low pressure
-@mu.g(ref='[6]_')
+@functor(var='mu.g')
 def Yoon_Thodos(T, Tc, Pc, MW):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) that estimates the gas hydraulic
+    viscosity (mu.g; in Pa*s) of a chemical using the Yoon Thodos method, as
+    described in [6]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    Pc : float
+        Critical point pressure [Pa].
+    MW : float
+        Molecular weight [g/mol].
+    
     Notes
     -----
     Calculates the viscosity of a gas using an emperical formula
@@ -300,7 +386,7 @@ def Yoon_Thodos(T, Tc, Pc, MW):
     >>> f(300.)
     1.0194885727776819e-05
     
-    '''
+    """
     Tr = T/Tc
     xi = 2173.4241*Tc**(1/6.)/(MW**0.5*Pc**(2/3.))
     a = 46.1
@@ -311,9 +397,22 @@ def Yoon_Thodos(T, Tc, Pc, MW):
     f = -4.058
     return (1. + a*Tr**b - c * exp(d*Tr) + e*exp(f*Tr))/(1E8*xi)
 
-@mu.g(ref='[7]_')
+@functor(var='mu.g')
 def Stiel_Thodos(T, Tc, Pc, MW):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) that estimates the gas hydraulic 
+    viscosity (mu.g; in Pa*s) of a chemical using the Stiel Thodos method, as 
+    described in [7]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    Pc : float
+        Critical point pressure [Pa].
+    MW : float
+        Molecular weight [g/mol].
+    
     Notes
     -----
     Calculates the viscosity of a gas using an emperical formula
@@ -331,7 +430,7 @@ def Stiel_Thodos(T, Tc, Pc, MW):
     >>> f(300.)
     1.0408926223608723e-05
     
-    '''
+    """
     Pc = Pc/101325.
     Tr = T/Tc
     xi = Tc**(1/6.)/(MW**0.5*Pc**(2/3.))
@@ -343,9 +442,28 @@ def Stiel_Thodos(T, Tc, Pc, MW):
 
 _lucas_Q_dict = {'7440-59-7': 1.38, '1333-74-0': 0.76, '7782-39-0': 0.52}
 
-@mu.g(ref='[5]_')
+@functor(var='mu.g')
 def Lucas_gas(T, Tc, Pc, Zc, MW, Q, dipole=0):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) that estimates the gas hydraulic 
+    viscosity (mu.g; in Pa*s) of a chemical using the Lucas gas method, as 
+    described in [5]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    Pc : float
+        Critical point pressure [Pa].
+    Zc : float
+        Critical compressibility [-].
+    MW : float
+        Molecular weight [g/mol].
+    dipole : float
+        Dipole momment [Debye].
+    Q : float
+        Regressed coefficient.
+    
     Notes
     -----
     Estimates the viscosity of a gas using an emperical
@@ -380,7 +498,7 @@ def Lucas_gas(T, Tc, Pc, Zc, MW, Q, dipole=0):
     >>> f(T=550)
     1.7822676912698928e-05
     
-    '''
+    """
     Tr = T/Tc
     xi = 0.176*(Tc/MW**3/(Pc/1E5)**4)**(1/6.)  # bar arrording to example in Poling
     if dipole is None:
@@ -403,9 +521,22 @@ def Lucas_gas(T, Tc, Pc, Zc, MW, Q, dipole=0):
     eta = (0.807*Tr**0.618 - 0.357*exp(-0.449*Tr) + 0.340*exp(-4.058*Tr) + 0.018)*Fp*FQ/xi
     return eta/1E7
 
-@mu.g(ref='[8]_')
+@functor(var='mu.g')
 def Gharagheizi_gas_viscosity(T, Tc, Pc, MW):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) that estimates the gas hydraulic 
+    viscosity (mu.g; in Pa*s) of a chemical using the Gharagheizi method, as 
+    described in [8]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    Pc : float
+        Critical point pressure [Pa].
+    MW : float
+        Molecular weight [g/mol].
+    
     Notes
     -----
     Calculates the viscosity of a gas using an emperical formula
@@ -429,7 +560,7 @@ def Gharagheizi_gas_viscosity(T, Tc, Pc, MW):
     >>> f(120.)
     5.215761625399613e-06
     
-    '''
+    """
     Tr = T/Tc
     mu_g = 1E-5*Pc*Tr + (0.091 - 0.477/MW)*T + MW*(1E-5*Pc - 8*MW**2/T**2)*(10.7639/Tc - 4.1929/T)
     return 1E-7 * abs(mu_g)
